@@ -41,18 +41,4 @@
   #endif
 #endif
 
-#ifndef WT_CXX11
-
-#if defined(__GXX_EXPERIMENTAL_CXX0X__) || __cplusplus >= 201103L || _MSC_VER >= 1900
-#define WT_CXX11
-#endif
-
-#ifdef WT_CXX11
-#define WT_CXX11ONLY(x) x
-#else
-#define WT_CXX11ONLY(x)
-#endif
-
-#endif
-
 #endif // DLLDEFS_H_
