@@ -32,8 +32,7 @@ enum class PopupTrigger {
   /*! \brief Shows popup when user clicks a drop down icon.
    *
    * The lineedit is modified to show a drop down icon, and clicking
-   * the icon shows the suggestions, very much like a WComboCox.
-   * line edit.
+   * the icon shows the suggestions, very much like a WComboBox.
    */
   DropDownIcon = 0x2
 };
@@ -490,12 +489,15 @@ private:
 
   std::vector<Wt::Signals::connection> modelConnections_;
 
+  std::string currentInputText_;
+
   JSignal<std::string> filter_;
   JSignal<std::string, std::string> jactivated_;
 
   std::vector<WFormWidget *> edits_;
 
   void init();
+  void scheduleFilter(std::string input);
   void doFilter(std::string input);
   void doActivate(std::string itemId, std::string editId);
   void connectObjJS(EventSignalBase& s, const std::string& methodName);
